==> mysql-5.7.33.tar.gz: mysql-5.7.33/client/dump/i_data_formatter.h <==
/*
  Copyright (c) 2015, Oracle and/or its affiliates. All rights reserved.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is also distributed with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have included with MySQL.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License, version 2.0, for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef I_DATA_FORMATTER_INCLUDED
#define I_DATA_FORMATTER_INCLUDED

#include "i_chain_element.h"
#include "item_processing_data.h"

namespace Mysql{
namespace Tools{
namespace Dump{

class I_data_formatter : public virtual I_chain_element
{
public:
  /**
    Creates string representation for output of DB object related to specified
    dump task object.
   */
  virtual void format_object(Item_processing_data* processing_data)= 0;
};

}
}
}

#endif

==> mysql-8.0_8.0.28.orig.tar.gz: mysql-8.0.28/client/dump/i_data_formatter.h <==
/*
  Copyright (c) 2015, 2021, Oracle and/or its affiliates.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is also distributed with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have included with MySQL.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License, version 2.0, for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef I_DATA_FORMATTER_INCLUDED
#define I_DATA_FORMATTER_INCLUDED

#include "client/dump/i_chain_element.h"
#include "client/dump/item_processing_data.h"

namespace Mysql {
namespace Tools {
namespace Dump {

class I_data_formatter : public virtual I_chain_element {
 public:
  /**
    Creates string representation for output of DB object related to specified
    dump task object.
   */
  virtual void format_object(Item_processing_data *processing_data) = 0;
};

}  // namespace Dump
}  // namespace Tools
}  // namespace Mysql

#endif
